Python SCTP Module
==================

This Python module is an encapsulation of the SCTP library provided by
*Linux* and *FreeBSD* operating systems (no other systems are
currently supported).

This module strictly implements the API described in **RFC 6458**.

Documentation
^^^^^^^^^^^^^

Module's documentation is hosted at https://py3-sctp.readthedocs.io.

